@@ -2,4 +2,4 @@
 //!
 //! Analogous to the `middleware` module in Actix Web.
 
-pub use crate::middleware_from_fn::{from_fn, MiddlewareFn, Next};
+pub use crate::middleware_from_fn::{from_fn, Next};
